"""Use-Cases: Search by literal names

Find a matching relative filepathname in upper directory
tree for a given name/relative path. 

**Example**:

See testdata/findnodes

Calls::
    
    getTopFromPathString
    setUpperTreeSearchPath
    findRelPathInSearchPath


"""