"""Use-Cases as PyUnit tests

These tests could either be called from the command line,
or within Eclipse by the plugin PyDev / PyUnit.
'setup.py' also supports the call by the parameter 'usecases'.

* setup.py: '*python setup.py usecases*'

* CLI: '*python -m unittest discover -s UseCases -p CallCase.py*' 

* Eclipse: Install PyDev, open the view PyUnit and proceed by
  'UseCases' package.

"""
__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2015-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.0'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__package__ = 'filesysobjects_pyunit'
